=========
CMS Plots
=========

.. image:: https://img.shields.io/github/issues-pr-raw/molssi-seamm/seamm_dashboard_client
   :target: https://github.com/molssi-seamm/seamm_dashboard_client/pulls
   :alt: GitHub pull requests

.. image:: https://github.com/molssi-seamm/seamm_dashboard_client/workflows/CI/badge.svg
   :target: https://github.com/molssi-seamm/seamm_dashboard_client/actions
   :alt: Build Status

.. image:: https://codecov.io/gh/molssi-seamm/seamm_dashboard_client/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/molssi-seamm/seamm_dashboard_client
   :alt: Code Coverage

.. image:: https://img.shields.io/lgtm/grade/python/g/molssi-seamm/seamm_dashboard_client.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/molssi-seamm/seamm_dashboard_client/context:python
   :alt: Code Quality

.. image:: https://github.com/molssi-seamm/seamm_dashboard_client/workflows/Documentation/badge.svg
   :target: https://molssi-seamm.github.io/seamm_dashboard_client/index.html
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/seamm_dashboard_client.svg
   :target: https://pypi.python.org/pypi/seamm_dashboard_client
   :alt: PyPi VERSION

Description
-----------

Utilities for creating plots for computational materials/molecular science (CMS)

This package provides tools for creating plotly graphs for e.g. band structure, DOS, and
other specialized plots for CMS applications.

* Free software: LGPL.v3 or later
* Documentation: https://molssi-seamm.github.io/seamm_dashboard_client/index.html

Features
--------

* Density of states (DOS) plots
* Band structure plots
* Combined band structure & DOS plots


Credits
---------

This package was created with Cookiecutter_ and the
`molssi-seamm/cookiecutter-seamm-plugin`_ project template.

Developed by the Molecular Sciences Software Institute (MolSSI_),
which receives funding from the National Science Foundation under
award ACI-1547580

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`molssi-seamm/cookiecutter-seamm-plugin`: https://github.com/molssi-seamm/cookiecutter-seamm-plugin
.. _MolSSI: https://molssi.org
